@@ -2,7 +2,7 @@
 
 # https://github.com/billythegoat356 https://github.com/loTus04 https://github.com/CSM-BlueRed
 
-# Version : 2.0 (added Colorate.Format, added Banner.Arrow, added Anime.Move, added Center.GroupAlign, added Center.TextAlign, updated Box to Banner, updated Box.Lines))
+# Version : 2.7 (added Colorate.Format, added Banner.Arrow, added Anime.Move, added Center.GroupAlign, added Center.TextAlign, updated Box to Banner, updated Box.Lines))
 
 # based on pyfade anc pycenter, R.I.P
 
@@ -694,13 +694,13 @@ class Write:
         if hide_cursor:
             Cursor.ShowCursor()
 
-    def Input(text: str, color: list, interval=0.05, hide_cursor: bool = True, input_color: str = Colors.reset, end: str = Colors.reset) -> str:
+    def Input(text: str, color: list, interval=0.05, hide_cursor: bool = True, input_color: str = Colors.reset, end: str = Colors.reset, func: function = input) -> str:
         if hide_cursor:
             Cursor.HideCursor()
 
         Write._write(text=text, color=color, interval=interval)
 
-        valor = input(input_color)
+        valor = func(input_color)
 
         _stdout.write(end)
         _stdout.flush()
